Module for checked code.
Structs
- Contains instrumented binary code of a program and initial memory size from memory import.
- The newtype contains the Code instance and the corresponding id (hash).
- The newtype contains the instrumented code and the corresponding id (hash).
- The newtype contains the instrumented code and the corresponding id (hash).
- Configuration for
Code::try_new_mock_. By default all checks enabled.
Enums
- Instrumentation error.
Constants
- Defines maximal permitted count of memory pages.
- Name of exports allowed on chain except execution kinds.