pub struct GasAllowanceCounter(/* private fields */);Expand description
Gas allowance counter with some predefined maximum value.
Implementations
Sourceimpl GasAllowanceCounter
impl GasAllowanceCounter
Sourcepub fn new(initial_amount: u64) -> Self
pub fn new(initial_amount: u64) -> Self
New limited gas allowance counter with initial value to spend.
Sourcepub fn charge<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
pub fn charge<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
Account for used gas allowance.
If there is no enough gas, then makes saturating charge and returns NotEnough.
Else charges gas and returns Enough.
Sourcepub fn charge_if_enough<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
pub fn charge_if_enough<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
Account for used gas allowance.
If there is no enough gas, then does nothing and returns ChargeResult::NotEnough.
Else charges gas and returns ChargeResult::Enough.