Struct gear_core::gas::GasCounter

source ·
pub struct GasCounter { /* private fields */ }
Gas counter with some predefined maximum gas.

Copy and Clone traits aren’t implemented for the type (however could be) in order to make the data only moveable, preventing explicit and implicit copying.

Implementations

source

impl GasCounter

source

pub fn new(initial_amount: u64) -> Self

New limited gas counter with initial gas to spend.

source

pub fn charge<T: Into<u64> + Copy>(&mut self, amount: T) -> ChargeResult

Account for used gas.

If there is no enough gas, then makes saturating charge and returns NotEnough. Else charges gas and returns Enough.

source

pub fn charge_if_enough<T: Into<u64> + Copy>( &mut self, amount: T ) -> ChargeResult

Account for used gas.

If there is no enough gas, then does nothing and returns ChargeResult::NotEnough. Else charges gas and returns ChargeResult::Enough.

source

pub fn reduce(&mut self, amount: u64) -> ChargeResult

Increase gas by amount.

Called when gas unreservation is occurred. Reduce gas by amount.

Called when message is sent to another program, so the gas amount is sent to receiving program. Or called when gas reservation is occurred.

In case of gas reservation: We don’t increase burn counter because GasTree manipulation is handled by separated function

source

pub fn left(&self) -> u64

Report how much gas is left.

source

pub fn burned(&self) -> u64

Report how much gas is burned.

source

pub fn to_amount(&self) -> GasAmount

Get gas amount.