LimitedStr

Struct LimitedStr 

pub struct LimitedStr<'a, const N: usize = 1024>(/* private fields */);
Wrapped string to fit given amount of bytes.

The Cow is used to avoid allocating a new String when the LimitedStr is created from a &str.

Plain str is not used because it can’t be properly encoded/decoded via scale codec.

Implementations

Source

impl<'a, const N: usize> LimitedStr<'a, N>

pub const MAX_LEN: usize = N

Maximum length of the string.

pub fn try_new<S: Into<Cow<'a, str>>>(s: S) -> Result<Self, LimitedStrError>

Constructs a limited string from a string.

Checks the size of the string.

pub fn truncated<S: Into<Cow<'a, str>>>(s: S) -> Self

Constructs a limited string from a string truncating it if it’s too long.

pub const fn from_small_str(s: &'static str) -> Self

Constructs a limited string from a static string literal small enough to fit the limit.

Should be used only with static string literals. In that case it can check the string length in compile time.

Panics

Can panic in runtime if the passed string is not a static string literal and is too long.

pub fn as_str(&self) -> &str

Return string slice.

pub fn into_inner(self) -> Cow<'a, str>

Return inner value.