pub struct GasInfo {
pub min_limit: u64,
pub reserved: u64,
pub burned: u64,
pub may_be_returned: u64,
pub waited: bool,
}Expand description
Pre-calculated gas consumption estimate for a message.
Intended to be used as a result in calculateGasFor* RPC calls.
Fields
min_limit: u64The minimum amount of gas required for successful execution.
reserved: u64The amount of gas that would be reserved.
burned: u64The amount of gas that would be burned.
may_be_returned: u64The amount of gas that may be returned.
waited: boolIndicates whether the message was placed into the waitlist.
This flag signifies that min_limit guarantees apply only to the first execution attempt.