pub enum ScheduledTask<RFM, SD, SUM> {
RemoveFromMailbox(RFM, MessageId),
RemoveFromWaitlist(ActorId, MessageId),
WakeMessage(ActorId, MessageId),
SendDispatch(SD),
SendUserMessage {
message_id: MessageId,
to_mailbox: SUM,
},
RemoveGasReservation(ActorId, ReservationId),
}Expand description
Scheduled task sense and required data for processing action.
CAUTION: NEVER ALLOW ScheduledTask BE A BIG DATA.
To avoid redundant migrations only append new variant(s) to the enum
with an explicit corresponding scale codec index.
Variants
RemoveFromMailbox(RFM, MessageId)
Remove message from mailbox as out of rent one.
RemoveFromWaitlist(ActorId, MessageId)
Remove message from waitlist as out of rent one.
WakeMessage(ActorId, MessageId)
Delayed wake of the message at concrete block.
SendDispatch(SD)
Delayed message to program sending.
The message itself stored in DispatchStash.
SendUserMessage
Delayed message to user sending.
The message itself stored in DispatchStash.
Fields

to_mailbox: SUMShould it be inserted into users mailbox.
RemoveGasReservation(ActorId, ReservationId)
Remove gas reservation.
Implementations
Sourceimpl<RFM, SD, SUM> ScheduledTask<RFM, SD, SUM>
impl<RFM, SD, SUM> ScheduledTask<RFM, SD, SUM>
Sourcepub fn process_with(self, handler: &mut impl TaskHandler<RFM, SD, SUM>) -> Gas
pub fn process_with(self, handler: &mut impl TaskHandler<RFM, SD, SUM>) -> Gas
Processing function of current task with given handler.