Module utils

Module utils 

Utility functions.

Functions

hash
Creates a unique identifier by passing given argument to blake2b hash-function.
hash_of_array
Creates a unique identifier by passing given argument to blake2b hash-function.