Struct gear_core::gas::GasAllowanceCounter
source · pub struct GasAllowanceCounter(_);Expand description
Gas allowance counter with some predefined maximum value.
Implementations
sourceimpl GasAllowanceCounter
impl GasAllowanceCounter
sourcepub fn new(initial_amount: u64) -> Self
pub fn new(initial_amount: u64) -> Self
New limited gas allowance counter with initial value to spend.
sourcepub fn charge<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
pub fn charge<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
Account for used gas allowance.
If there is no enough gas, then makes saturating charge and returns NotEnough.
Else charges gas and returns Enough.
sourcepub fn charge_if_enough<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
pub fn charge_if_enough<T: Into<u64>>(&mut self, amount: T) -> ChargeResult
Account for used gas allowance.
If there is no enough gas, then does nothing and returns ChargeResult::NotEnough.
Else charges gas and returns ChargeResult::Enough.