pub struct LimitedStr<'a, const N: usize = 1024>(/* private fields */);Expand description
Implementations
Sourceimpl<'a, const N: usize> LimitedStr<'a, N>
impl<'a, const N: usize> LimitedStr<'a, N>
Sourcepub fn from_utf8(vec: LimitedVec<u8, N>) -> Result<Self, FromUtf8Error>
pub fn from_utf8(vec: LimitedVec<u8, N>) -> Result<Self, FromUtf8Error>
Constructs a limited string from a limited vector of bytes of the same size.
Sourcepub fn try_new<S: Into<Cow<'a, str>>>(s: S) -> Result<Self, LimitedStrError>
pub fn try_new<S: Into<Cow<'a, str>>>(s: S) -> Result<Self, LimitedStrError>
Constructs a limited string from a string.
Checks the size of the string.
Sourcepub fn truncated<S: Into<Cow<'a, str>>>(s: S) -> Self
pub fn truncated<S: Into<Cow<'a, str>>>(s: S) -> Self
Constructs a limited string from a string truncating it if it’s too long.
Sourcepub const fn from_small_str(s: &'static str) -> Self
pub const fn from_small_str(s: &'static str) -> Self
Constructs a limited string from a static string literal small enough to fit the limit.
Should be used only with static string literals. In that case it can check the string length in compile time.
Panics
Can panic in runtime if the passed string is not a static string literal and is too long.
Sourcepub fn into_inner(self) -> Cow<'a, str>
pub fn into_inner(self) -> Cow<'a, str>
Return inner value.