pub struct ReservationNonce(/* private fields */);Expand description
An unchangeable wrapper over u64 value, which is required to be used as a “view-only” reservations nonce in a message execution context.
Note:
By contract, It must be instantiated only once, when message execution context is created. Also the latter is required to be instantiated only once, when incoming dispatch is created.